@@ -1,9 +1,9 @@
 /* File cphead.c
- * September 1, 2011
+ * March 3, 2015
  * By Jessica Mink Harvard-Smithsonian Center for Astrophysics)
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 2000-2011
+   Copyright (C) 2000-2015
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -41,7 +41,7 @@ static void CopyValues();
 extern char *GetFITShead();
 
 static int verbose = 0;		/* verbose/debugging flag */
-static char *RevMsg = "CPHEAD WCSTools 3.9.1, 06 February 2015, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "CPHEAD WCSTools 3.9.2, 15 May 2015, Jessica Mink (jmink@cfa.harvard.edu)";
 static int copyall = 0;		/* Copy entire header, overwriting old one */
 static int nfile = 0;
 static int ndec0 = -9;
@@ -662,8 +662,13 @@ char	*kwd[];		/* Names of keywords for which to copy values */
 	    }
 	}
 
-    free (header);
-    free (headout);
+    if (header == headout) {
+	free (header);
+	}
+    else {
+	free (header);
+	free (headout);
+	}
     return;
 }
 
@@ -699,4 +704,6 @@ char	*kwd[];		/* Names of keywords for which to copy values */
  *
  * Mar 14 2011	Use MAXPV from wcslib.h when copying PVi_j parameters
  * Sep  1 2011	Fix overflow bug by increasing size of history from 72 to 128
+ *
+ * Mar  3 2015	Only free headout if it is different from header
  */
