@@ -37,7 +37,7 @@
 #define MAXFILES	2000
 #define MAXLINES	100000
 
-static char *RevMsg = "GETCOL WCSTools 3.9.1, 06 February 2015, Jessica Mink SAO";
+static char *RevMsg = "GETCOL WCSTools 3.9.2, 15 May 2015, Jessica Mink SAO";
 
 static void usage();
 static int ListFile();
