@@ -41,7 +41,7 @@ static void MatchCat();
 #define MAXFILES 1000
 static int maxnfile = MAXFILES;
 
-static char *RevMsg = "WCSTools 3.9.1, 06 February 2015, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "WCSTools 3.9.2, 15 May 2015, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int rot = 0;
