@@ -190,13 +190,13 @@ struct WorldCoor {
 #define WCS_CSC 24	/* COBE quadrilateralized Spherical Cube */
 #define WCS_QSC 25	/* Quadrilateralized Spherical Cube */
 #define WCS_TSC 26	/* Tangential Spherical Cube */
-#define WCS_NCP 27	/* Special case of SIN */
-#define WCS_GLS 28	/* Same as SFL */
+#define WCS_NCP 27	/* Special case of SIN from AIPS*/
+#define WCS_GLS 28	/* Same as SFL from AIPS*/
 #define WCS_DSS 29	/* Digitized Sky Survey plate solution */
 #define WCS_PLT 30	/* Plate fit polynomials (SAO) */
-#define WCS_TNX 31	/* Gnomonic = Tangent Plane (NOAO with corrections) */
-#define WCS_ZPX 32	/* Gnomonic = Tangent Plane (NOAO with corrections) */
-#define WCS_TPV 33	/* Gnomonic = Tangent Plane (NOAO with corrections) */
+#define WCS_TNX 31	/* Tangent Plane (NOAO corrections) */
+#define WCS_ZPX 32	/* Zenithal Azimuthal Polynomial (NOAO corrections) */
+#define WCS_TPV 33	/* Tangent Plane (SCAMP corrections) */
 #define NWCSTYPE 34	/* Number of WCS types (-1 really means no WCS) */
 
 /* Coordinate systems */
