@@ -1,9 +1,9 @@
 /* File remap.c
- * February 19, 2014
+ * March 19, 2015
  * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1999-2014
+   Copyright (C) 1999-2015
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -49,7 +49,7 @@ static char *outname0 = "remap.fits";
 static char *outname;
 static char *wcsproj;           /* WCS projection name */
 
-static char *RevMsg = "REMAP WCSTools 3.9.1, 06 February 2015, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "REMAP WCSTools 3.9.2, 15 May 2015, Jessica Mink (jmink@cfa.harvard.edu)";
 static int nfiles = 0;
 static int fitsout = 1;
 static double secpix = 0;
@@ -427,6 +427,7 @@ char	*filename;	/* FITS or IRAF file filename */
     char history[80];
     char wcstemp[16];
     struct WorldCoor *GetWCSFITS();
+    struct WorldCoor *GetFITSWCS();
     double *imvec;
     int npix;
     int addscale = 0;
@@ -947,4 +948,6 @@ double	*y2;		/* Upper right y coordinate (returned) */
  * Sep 17 2013  Include fitswcs.h
  *
  * Feb 19 2014	Update usage to -f WCSfile suggested by Steve Willner
+ *
+ * Mar 19 2015	Declare GetFITSWCS()
  */
