@@ -39,7 +39,7 @@ static void usage();
 static void SumPix();
 extern double PhotPix();
 
-static char *RevMsg = "SUMPIX WCSTools 3.9.1, 06 February 2015, Jessica Mink SAO";
+static char *RevMsg = "SUMPIX WCSTools 3.9.2, 15 May 2015, Jessica Mink SAO";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int version = 0;	/* If 1, print only program name and version */
